import uuid

from barker.models.meta import Base
from sqlalchemy import Column, ForeignKey, Numeric, UniqueConstraint, text
from sqlalchemy.dialects.postgresql import UUID
from sqlalchemy.orm import relationship


class InventoryModifier(Base):
    __tablename__ = "inventory_modifiers"
    __table_args__ = (UniqueConstraint("inventory_id", "modifier_id"),)

    id = Column(
        "id", UUID(as_uuid=True), primary_key=True, server_default=text("gen_random_uuid()"), default=uuid.uuid4
    )
    inventory_id = Column("inventory_id", UUID(as_uuid=True), ForeignKey("inventories.id"), nullable=False)
    modifier_id = Column("modifier_id", UUID(as_uuid=True), ForeignKey("modifiers.id"), nullable=False)
    price = Column("price", Numeric(precision=15, scale=2), nullable=False)

    inventory = relationship("Inventory", backref="modifiers")
    modifier = relationship("Modifier")

    def __init__(self, inventory_id, modifier_id, price):
        self.inventory_id = inventory_id
        self.modifier_id = modifier_id
        self.price = price
