import uuid

from decimal import Decimal
from typing import List, Optional

from pydantic import BaseModel, Field

from . import to_camel


class DiscountItem(BaseModel):
    id_: uuid.UUID
    name: str
    discount: Decimal = Field(ge=0, multiple_of=0.0001, default=0, le=1)
    discount_limit: Optional[Decimal]
    customer_discount: Optional[Decimal]

    class Config:
        alias_generator = to_camel


class CustomerIn(BaseModel):
    name: str = Field(..., min_length=1)
    # phone: str = Field(..., min_length=1)
    phone: str
    address: Optional[str]

    discounts: List[DiscountItem]

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel


class Customer(CustomerIn):
    id_: uuid.UUID

    class Config:
        fields = {"id_": "id"}
        anystr_strip_whitespace = True
        alias_generator = to_camel


class CustomerLink(BaseModel):
    id_: uuid.UUID = Field(...)
    name: Optional[str]

    class Config:
        fields = {"id_": "id"}


class CustomerBlank(CustomerIn):
    name: str

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel
