import uuid

from datetime import datetime
from typing import Optional

from pydantic import BaseModel, Field

from . import to_camel
from .section import SectionLink


class DeviceIn(BaseModel):
    name: str = Field(..., min_length=1)
    enabled: bool
    section: SectionLink

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel


class Device(DeviceIn):
    id_: uuid.UUID
    creation_date: datetime
    last_user: str
    last_date: Optional[datetime]

    class Config:
        fields = {"id_": "id"}
        anystr_strip_whitespace = True
        alias_generator = to_camel
        json_encoders = {datetime: lambda v: v.strftime("%d-%b-%Y %H:%M")}


class DeviceLink(BaseModel):
    id_: uuid.UUID = Field(...)
    name: Optional[str]

    class Config:
        fields = {"id_": "id"}
        alias_generator = to_camel
