from datetime import date, datetime
from decimal import Decimal
from typing import List

from pydantic import BaseModel, validator

from . import to_camel


class DiscountReportItem(BaseModel):
    name: str
    amount: Decimal

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel


class DiscountReport(BaseModel):
    start_date: date
    finish_date: date
    amounts: List[DiscountReportItem]

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel
        json_encoders = {datetime: lambda v: v.strftime("%d-%b-%Y %H:%M"), date: lambda v: v.strftime("%d-%b-%Y")}

    @validator("start_date", pre=True)
    def parse_start_date(cls, value):
        if isinstance(value, date):
            return value
        return datetime.strptime(value, "%d-%b-%Y").date()

    @validator("finish_date", pre=True)
    def parse_finish_date(cls, value):
        if isinstance(value, date):
            return value
        return datetime.strptime(value, "%d-%b-%Y").date()
