import uuid

from typing import List, Optional

from pydantic import BaseModel, Field

from . import to_camel
from .menu_category import MenuCategoryLink


class ModifierCategoryIn(BaseModel):
    name: str = Field(..., min_length=1)
    minimum: int = Field(ge=0)
    maximum: Optional[int] = Field(ge=0)
    is_active: bool
    menu_categories: List[MenuCategoryLink]

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel


class ModifierCategory(ModifierCategoryIn):
    id_: uuid.UUID
    sort_order: int

    class Config:
        fields = {"id_": "id"}
        anystr_strip_whitespace = True
        alias_generator = to_camel


class ModifierCategoryBlank(ModifierCategoryIn):
    name: str

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel


class ModifierCategoryLink(BaseModel):
    id_: uuid.UUID = Field(...)
    name: Optional[str]

    class Config:
        fields = {"id_": "id"}
