import uuid

from decimal import Decimal
from typing import Optional

from pydantic import BaseModel, Field

from . import to_camel
from .tax import TaxLink


class SaleCategoryIn(BaseModel):
    name: str = Field(..., min_length=1)
    discount_limit: Decimal = Field(ge=0, multiple_of=0.0001, default=0, le=1)
    tax: TaxLink = Field(...)

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel


class SaleCategory(SaleCategoryIn):
    id_: uuid.UUID

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel


class SaleCategoryBlank(SaleCategoryIn):
    name: str
    tax: Optional[TaxLink]

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel


class SaleCategoryForDiscount(SaleCategory):
    discount: Decimal
    tax: Optional[TaxLink]

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel


class SaleCategoryLink(BaseModel):
    id_: uuid.UUID = Field(...)
    name: Optional[str]

    class Config:
        fields = {"id_": "id"}
