import uuid

from datetime import date, datetime
from decimal import Decimal
from typing import List, Optional

from pydantic import BaseModel, validator

from . import to_camel


class UpdateProductPricesItem(BaseModel):
    id: uuid.UUID
    name: str
    old_price: Decimal
    new_price: Decimal

    class Config:
        alias_generator = to_camel


class UpdateProductPrices(BaseModel):
    date_: date
    menu_category_id: Optional[uuid.UUID]
    items: List[UpdateProductPricesItem]

    class Config:
        alias_generator = to_camel
        json_encoders = {date: lambda v: v.strftime("%d-%b-%Y")}

    @validator("date_", pre=True)
    def parse_date(cls, value):
        if isinstance(value, date):
            return value
        return datetime.strptime(value, "%d-%b-%Y").date()
