import { NgModule } from '@angular/core';
import { Routes, RouterModule } from '@angular/router';

import { LoginComponent } from './auth/login/login.component';
import { LogoutComponent } from './auth/logout/logout.component';
import { HomeComponent } from './home/home.component';

const routes: Routes = [
  {
    path: 'beer-sale-report',
    loadChildren: () =>
      import('./beer-sale-report/beer-sale-report.module').then((mod) => mod.BeerSaleReportModule),
  },
  {
    path: 'bill-settlement-report',
    loadChildren: () =>
      import('./bill-settlement-report/bill-settlement-report.module').then(
        (mod) => mod.BillSettlementReportModule,
      ),
  },
  {
    path: 'cashier-report',
    loadChildren: () =>
      import('./cashier-report/cashier-report.module').then((mod) => mod.CashierReportModule),
  },
  {
    path: 'customers',
    loadChildren: () => import('./customers/customer.module').then((mod) => mod.CustomerModule),
  },
  {
    path: 'devices',
    loadChildren: () => import('./devices/devices.module').then((mod) => mod.DevicesModule),
  },
  {
    path: 'discount-report',
    loadChildren: () =>
      import('./discount-report/discount-report.module').then((mod) => mod.DiscountReportModule),
  },
  {
    path: 'guest-book',
    loadChildren: () => import('./guest-book/guest-book.module').then((mod) => mod.GuestBookModule),
  },
  {
    path: 'header-footer',
    loadChildren: () =>
      import('./header-footer/header-footer.module').then((mod) => mod.HeaderFooterModule),
  },
  {
    path: 'modifiers',
    loadChildren: () => import('./modifiers/modifiers.module').then((mod) => mod.ModifiersModule),
  },
  {
    path: 'modifier-categories',
    loadChildren: () =>
      import('./modifier-categories/modifier-categories.module').then(
        (mod) => mod.ModifierCategoriesModule,
      ),
  },
  {
    path: 'printers',
    loadChildren: () => import('./printers/printers.module').then((mod) => mod.PrintersModule),
  },
  {
    path: 'products',
    loadChildren: () => import('./product/products.module').then((mod) => mod.ProductsModule),
  },
  {
    path: 'product-sale-report',
    loadChildren: () =>
      import('./product-sale-report/product-sale-report.module').then(
        (mod) => mod.ProductSaleReportModule,
      ),
  },
  {
    path: 'product-updates-report',
    loadChildren: () =>
      import('./product-updates-report/product-updates-report.module').then(
        (mod) => mod.ProductUpdatesReportModule,
      ),
  },
  {
    path: 'menu-categories',
    loadChildren: () =>
      import('./menu-category/menu-categories.module').then((mod) => mod.MenuCategoriesModule),
  },
  {
    path: 'roles',
    loadChildren: () => import('./roles/roles.module').then((mod) => mod.RolesModule),
  },
  {
    path: 'sales',
    loadChildren: () => import('./sales/sales.module').then((mod) => mod.SalesModule),
  },
  {
    path: 'sale-report',
    loadChildren: () =>
      import('./sale-report/sale-report.module').then((mod) => mod.SaleReportModule),
  },
  {
    path: 'sale-categories',
    loadChildren: () =>
      import('./sale-category/sale-categories.module').then((mod) => mod.SaleCategoriesModule),
  },
  {
    path: 'sections',
    loadChildren: () => import('./sections/sections.module').then((mod) => mod.SectionsModule),
  },
  {
    path: 'section-printers',
    loadChildren: () =>
      import('./section-printers/section-printers.module').then((mod) => mod.SectionPrintersModule),
  },
  {
    path: 'settings',
    loadChildren: () => import('./settings/settings.module').then((mod) => mod.SettingsModule),
  },
  {
    path: 'settle-options',
    loadChildren: () =>
      import('./settle-option/settle-options.module').then((mod) => mod.SettleOptionsModule),
  },
  {
    path: 'tables',
    loadChildren: () => import('./tables/tables.module').then((mod) => mod.TableModule),
  },
  {
    path: 'taxes',
    loadChildren: () => import('./taxes/taxes.module').then((mod) => mod.TaxesModule),
  },
  {
    path: 'tax-report',
    loadChildren: () => import('./tax-report/tax-report.module').then((mod) => mod.TaxReportModule),
  },
  {
    path: 'update-product-prices',
    loadChildren: () =>
      import('./update-product-prices/update-product-prices.module').then(
        (mod) => mod.UpdateProductPricesModule,
      ),
  },
  {
    path: 'users',
    loadChildren: () => import('./users/users.module').then((mod) => mod.UsersModule),
  },
  { path: 'login', component: LoginComponent },
  { path: 'logout', component: LogoutComponent },
  { path: '', component: HomeComponent },
];
@NgModule({
  imports: [
    RouterModule.forRoot(routes, {
      onSameUrlNavigation: 'reload',
      relativeLinkResolution: 'legacy',
    }),
  ],
  exports: [RouterModule],
})
export class AppRoutingModule {}
