import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup } from '@angular/forms';
import { ActivatedRoute, Router } from '@angular/router';
import * as moment from 'moment';

import { ToCsvService } from '../shared/to-csv.service';

import { BeerSaleExportHeaderInterface } from './beer-sale-export-header-interface';
import { BeerSaleReport } from './beer-sale-report';
import { BeerSaleReportDataSource } from './beer-sale-report-datasource';

@Component({
  selector: 'app-beer-sale-report',
  templateUrl: './beer-sale-report.component.html',
  styleUrls: ['./beer-sale-report.component.css'],
})
export class BeerSaleReportComponent implements OnInit {
  info: BeerSaleReport = new BeerSaleReport();
  dataSource: BeerSaleReportDataSource = new BeerSaleReportDataSource(this.info.data);
  form: FormGroup;

  /** Columns displayed in the table. Columns IDs can be added, removed, or reordered. */
  displayedColumns: string[] = ['date'];

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private fb: FormBuilder,
    private toCsv: ToCsvService,
  ) {
    // Create form
    this.form = this.fb.group({
      startDate: '',
      finishDate: '',
    });
  }

  ngOnInit() {
    this.route.data.subscribe((value) => {
      const data = value as { info: BeerSaleReport };
      this.info = data.info;
      this.displayedColumns = ['date'].concat(this.info.headers);
      this.form.setValue({
        startDate: moment(this.info.startDate, 'DD-MMM-YYYY').toDate(),
        finishDate: moment(this.info.finishDate, 'DD-MMM-YYYY').toDate(),
      });
      this.dataSource = new BeerSaleReportDataSource(this.info.data);
    });
  }

  show() {
    const info = this.getInfo();
    this.router.navigate(['beer-sale-report'], {
      queryParams: {
        startDate: info.startDate,
        finishDate: info.finishDate,
      },
    });
  }

  getInfo(): BeerSaleReport {
    const formModel = this.form.value;

    return new BeerSaleReport({
      startDate: moment(formModel.startDate).format('DD-MMM-YYYY'),
      finishDate: moment(formModel.finishDate).format('DD-MMM-YYYY'),
    });
  }

  exportCsv() {
    const init: BeerSaleExportHeaderInterface = { Date: 'date' };
    const headers = this.info.headers.reduce((a, c) => {
      a[c] = c;
      return a;
    }, init);
    const csvData = new Blob([this.toCsv.toCsv(headers, this.info.data)], {
      type: 'text/csv;charset=utf-8;',
    });
    const link = document.createElement('a');
    link.href = window.URL.createObjectURL(csvData);
    link.setAttribute('download', 'beer-sale-report.csv');
    document.body.appendChild(link);
    link.click();
    document.body.removeChild(link);
  }
}
