import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup } from '@angular/forms';
import { ActivatedRoute, Router } from '@angular/router';
import * as moment from 'moment';

import { ToCsvService } from '../shared/to-csv.service';

import { BillSettlementReport } from './bill-settlement-report';
import { BillSettlementReportDataSource } from './bill-settlement-report-datasource';

@Component({
  selector: 'app-bill-settlement-report',
  templateUrl: './bill-settlement-report.component.html',
  styleUrls: ['./bill-settlement-report.component.css'],
})
export class BillSettlementReportComponent implements OnInit {
  info: BillSettlementReport = new BillSettlementReport();
  dataSource: BillSettlementReportDataSource = new BillSettlementReportDataSource(
    this.info.amounts,
  );

  form: FormGroup;

  /** Columns displayed in the table. Columns IDs can be added, removed, or reordered. */
  displayedColumns = ['date', 'billId', 'amount', 'settlement'];

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private fb: FormBuilder,
    private toCsv: ToCsvService,
  ) {
    // Create form
    this.form = this.fb.group({
      startDate: '',
      finishDate: '',
    });
  }

  ngOnInit() {
    this.route.data.subscribe((value) => {
      const data = value as { info: BillSettlementReport };
      this.info = data.info;
      this.form.setValue({
        startDate: moment(this.info.startDate, 'DD-MMM-YYYY').toDate(),
        finishDate: moment(this.info.finishDate, 'DD-MMM-YYYY').toDate(),
      });
      this.dataSource = new BillSettlementReportDataSource(this.info.amounts);
    });
  }

  show() {
    const info = this.getInfo();
    this.router.navigate(['bill-settlement-report'], {
      queryParams: {
        startDate: info.startDate,
        finishDate: info.finishDate,
      },
    });
  }

  getInfo(): BillSettlementReport {
    const formModel = this.form.value;

    return new BillSettlementReport({
      startDate: moment(formModel.startDate).format('DD-MMM-YYYY'),
      finishDate: moment(formModel.finishDate).format('DD-MMM-YYYY'),
    });
  }

  exportCsv() {
    const headers = {
      Date: 'date',
      BillID: 'billId',
      Amount: 'amount',
      Settlement: 'settlement',
    };
    const csvData = new Blob([this.toCsv.toCsv(headers, this.dataSource.data)], {
      type: 'text/csv;charset=utf-8;',
    });
    const link = document.createElement('a');
    link.href = window.URL.createObjectURL(csvData);
    link.setAttribute('download', 'bill-settlement-report.csv');
    document.body.appendChild(link);
    link.click();
    document.body.removeChild(link);
  }
}
