import { CommonModule } from '@angular/common';
import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';

import { AuthGuard } from '../auth/auth-guard.service';
import { SectionListResolver } from '../sections/section-list-resolver.service';

import { DeviceDetailComponent } from './device-detail/device-detail.component';
import { DeviceListResolver } from './device-list-resolver.service';
import { DeviceListComponent } from './device-list/device-list.component';
import { DeviceResolver } from './device-resolver.service';

const devicesRoutes: Routes = [
  {
    path: '',
    component: DeviceListComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Devices',
    },
    resolve: {
      list: DeviceListResolver,
    },
  },
  {
    path: 'new',
    component: DeviceDetailComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Devices',
    },
    resolve: {
      item: DeviceResolver,
      sections: SectionListResolver,
    },
  },
  {
    path: ':id',
    component: DeviceDetailComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Devices',
    },
    resolve: {
      item: DeviceResolver,
      sections: SectionListResolver,
    },
  },
];

@NgModule({
  imports: [CommonModule, RouterModule.forChild(devicesRoutes)],
  exports: [RouterModule],
  providers: [DeviceListResolver, DeviceResolver],
})
export class DevicesRoutingModule {}
