import { CdkDragDrop, moveItemInArray } from '@angular/cdk/drag-drop';
import { Component, OnInit, ViewChild } from '@angular/core';
import { MatTable } from '@angular/material/table';
import { ActivatedRoute, Router } from '@angular/router';
import { BehaviorSubject } from 'rxjs';

import { MenuCategory } from '../../core/menu-category';
import { ToasterService } from '../../core/toaster.service';
import { MenuCategoryService } from '../menu-category.service';

import { MenuCategoryListDatasource } from './menu-category-list-datasource';

@Component({
  selector: 'app-menu-category-list',
  templateUrl: './menu-category-list.component.html',
  styleUrls: ['./menu-category-list.component.css'],
})
export class MenuCategoryListComponent implements OnInit {
  @ViewChild('table', { static: true }) table?: MatTable<MenuCategory>;
  list: MenuCategory[] = [];
  data: BehaviorSubject<MenuCategory[]> = new BehaviorSubject<MenuCategory[]>(this.list);
  dataSource: MenuCategoryListDatasource = new MenuCategoryListDatasource(this.data);
  /** Columns displayed in the table. Columns IDs can be added, removed, or reordered. */
  displayedColumns = ['name', 'isActive', 'isFixture'];

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private toaster: ToasterService,
    private ser: MenuCategoryService,
  ) {
    this.data.subscribe((data: MenuCategory[]) => {
      this.list = data;
    });
  }

  ngOnInit() {
    this.route.data.subscribe((value) => {
      const data = value as { list: MenuCategory[] };
      this.data.next(data.list);
    });
    this.dataSource = new MenuCategoryListDatasource(this.data);
  }

  updateSortOrder() {
    this.ser.updateSortOrder(this.list).subscribe(
      () => {
        this.toaster.show('Success', '');
      },
      (error) => {
        this.toaster.show('Error', error);
      },
    );
  }

  dropTable(event: CdkDragDrop<MenuCategoryListDatasource>) {
    const prevIndex = this.list.indexOf(event.item.data);
    moveItemInArray(this.list, prevIndex, event.currentIndex);
    this.data.next(this.list);
  }
}
