import { Component, OnInit, ViewChild } from '@angular/core';
import { FormBuilder, FormGroup } from '@angular/forms';
import { MatSelectChange } from '@angular/material/select';
import { MatTable } from '@angular/material/table';
import { ActivatedRoute, Router } from '@angular/router';
import { BehaviorSubject } from 'rxjs';

import { Modifier } from '../../core/modifier';
import { ModifierCategory } from '../../core/modifier-category';

import { ModifierListDataSource } from './modifier-list-datasource';

@Component({
  selector: 'app-modifier-list',
  templateUrl: './modifier-list.component.html',
  styleUrls: ['./modifier-list.component.css'],
})
export class ModifierListComponent implements OnInit {
  @ViewChild('table', { static: true }) table?: MatTable<Modifier>;
  filter: BehaviorSubject<string> = new BehaviorSubject('');
  data: BehaviorSubject<Modifier[]> = new BehaviorSubject<Modifier[]>([]);
  dataSource: ModifierListDataSource = new ModifierListDataSource(this.filter, this.data);
  form: FormGroup;
  list: Modifier[] = [];
  modifierCategories: ModifierCategory[] = [];
  /** Columns displayed in the table. Columns IDs can be added, removed, or reordered. */
  displayedColumns: string[] = ['name', 'showInBill', 'price', 'isActive', 'modifierCategory'];

  constructor(private route: ActivatedRoute, private fb: FormBuilder, private router: Router) {
    this.form = this.fb.group({
      modifierCategory: '',
    });
    this.data.subscribe((data: Modifier[]) => {
      this.list = data;
    });
  }

  filterOn(val: MatSelectChange) {
    this.filter.next(val.value);
  }

  ngOnInit() {
    this.route.data.subscribe((value) => {
      const data = value as { list: Modifier[]; modifierCategories: ModifierCategory[] };
      this.data.next(data.list);
      this.modifierCategories = data.modifierCategories;
    });
    this.dataSource = new ModifierListDataSource(this.filter, this.data);
  }
}
