import { HttpClient, HttpParams } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs/internal/Observable';
import { catchError } from 'rxjs/operators';

import { ErrorLoggerService } from '../core/error-logger.service';

import { ProductSaleReport } from './product-sale-report';

const url = '/api/product-sale-report';
const serviceName = 'ProductSaleReportService';

@Injectable({
  providedIn: 'root',
})
export class ProductSaleReportService {
  constructor(private http: HttpClient, private log: ErrorLoggerService) {}

  get(startDate: string | null, finishDate: string | null): Observable<ProductSaleReport> {
    const options = { params: new HttpParams() };
    if (startDate !== null) {
      options.params = options.params.set('s', startDate);
    }
    if (finishDate !== null) {
      options.params = options.params.set('f', finishDate);
    }
    return this.http
      .get<ProductSaleReport>(url, options)
      .pipe(catchError(this.log.handleError(serviceName, 'get'))) as Observable<ProductSaleReport>;
  }
}
