import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs/internal/Observable';
import { catchError } from 'rxjs/operators';

import { ErrorLoggerService } from '../core/error-logger.service';
import { Table } from '../core/table';

const httpOptions = {
  headers: new HttpHeaders({ 'Content-Type': 'application/json' }),
};
const url = '/api/tables';
const serviceName = 'TableService';

@Injectable({
  providedIn: 'root',
})
export class TableService {
  constructor(private http: HttpClient, private log: ErrorLoggerService) {}

  get(id: string | null): Observable<Table> {
    const getUrl: string = id === null ? url : `${url}/${id}`;
    return this.http
      .get<Table>(getUrl)
      .pipe(catchError(this.log.handleError(serviceName, `get id=${id}`))) as Observable<Table>;
  }

  list(): Observable<Table[]> {
    return this.http
      .get<Table[]>(`${url}/list`)
      .pipe(catchError(this.log.handleError(serviceName, 'list'))) as Observable<Table[]>;
  }

  running(): Observable<Table[]> {
    return this.http
      .get<Table[]>(`${url}/running`)
      .pipe(catchError(this.log.handleError(serviceName, 'running'))) as Observable<Table[]>;
  }

  save(tables: Table): Observable<Table> {
    return this.http
      .post<Table>(url, tables, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'save'))) as Observable<Table>;
  }

  update(tables: Table): Observable<Table> {
    return this.http
      .put<Table>(`${url}/${tables.id}`, tables, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'update'))) as Observable<Table>;
  }

  updateSortOrder(list: Table[]): Observable<boolean> {
    return this.http
      .post<Table[]>(`${url}/list`, list, httpOptions)
      .pipe(
        catchError(this.log.handleError(serviceName, 'updateSortOrder')),
      ) as Observable<boolean>;
  }

  saveOrUpdate(tables: Table): Observable<Table> {
    if (!tables.id) {
      return this.save(tables);
    }
    return this.update(tables);
  }

  delete(id: string): Observable<Table> {
    return this.http
      .delete<Table>(`${url}/${id}`, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'delete'))) as Observable<Table>;
  }
}
